#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
import launchctl
import launchagents
import mac_tag

"""
.plist colors:
    none    running with exit status - or 0
    gray    unloaded
    red     running with exit status != 0

folder colors:
    none    folder without LaunchAgents with exit status != 0
    red     exit status != 0
"""


LAUNCHAGENTS = os.path.join(os.environ["HOME"], "Library", "LaunchAgents")


JOBS = launchctl.jobs()


def _job(label):
    for job in JOBS:
        if job.label == label:
            return job


def _tree(path, top):
    while path != os.path.dirname(top):
        yield path
        path = os.path.dirname(path)


class _Colors:
    def __init__(self):
        self.none = []
        self.gray = []
        self.red = []

    def colorize(self):
        mac_tag.remove([], list(set(self.none)))
        mac_tag.set(["gray"], list(set(self.gray)))
        mac_tag.set(["red"], list(set(self.red)))


def colorize(path):
    colors = _Colors()
    files = launchagents.find(path)
    tree = []
    for f in files:
        paths = list(_tree(f, path))
        data = launchagents.read(f)
        job = _job(data.get("Label", None))
        if not job:
            colors.gray += [f]
        if job and job.status != 0:  # error
            colors.red += paths
    colors.none = list(filter(lambda p: p not in colors.red + colors.gray, tree))
    colors.colorize()


USAGE = 'usage: python -m launchagents.colorize [path]'


def _cli():
    path = LAUNCHAGENTS
    if len(sys.argv) == 2:
        path = sys.argv[1]
    colorize(path)


if __name__ == '__main__':
    _cli()
